/*
  oled_text_example_code.c
  http://learn.parallax.com/propeller-c-tutorials 
  This program demos how to set up communication from your computer to the oled, how to set up.
  text size, color and screen rotation along with other basic commands used with OLED 0.95" 96X64 product 28087. Be sure to upload
  the font loader program included in this zip file onto your board before using text commands. The font loader needs to be loaded to your board only once so that 
  your board will accept certain text commands.
  Author: Parallax Inc
  Date: 9/28/2016
*/
#include "simpletools.h"                          // Include simple tools.
#include "oledc.h"                                // Include oled screen library.


//Set up SPI pins.
#define SID  6                                    // Serial data in.
#define SCLK 7                                    // Clock.
#define CS   8                                    // Chip select.
#define RS   9                                
#define RST  10                                

#define SCRN_ROT  0                               // Screen rotation chosse between  0, 1, 2, 3,
#define SCRN_ROT1 1
#define SCRN_ROT2 2
#define SCRN_ROT3 3



int main()                                        // Main function
{
  
 oledc_init(SID,SCLK,CS,RS,RST,SCRN_ROT);         // Initiate serial communication.
 oledc_setTextSize(1);                            // Set text size. Select from sizes is 1, 2, or 3.
 oledc_setTextColor(WHITE, BLUE);                 // Set text color as well as background behind text.
 oledc_setTextSize(2);                            // Demo text size 2. 
 oledc_drawText("Parallax Inc.");


// Demo rotation, drawing numbers, and clearing the screen. 

 oledc_setRotation(SCRN_ROT);                     // Set rotation to 0.
 oledc_drawNumber(64,3);                          // Draw a number with no places after the decimal.
 pause(1000);                                     // Pause for one second to allow demo to complete.
 oledc_clear(0,0,oledc_getWidth(),oledc_getHeight()); // Demo for clear screen command. (x, y, width, height).                           
 
 
 oledc_setRotation(SCRN_ROT1);                    // Set rotation to 1.
 oledc_drawNumber(64,2);                          // Draw a number with one one place after the decimal.
 pause(1000);                                     // Pause for one second to allow demo to complete.
 
    
 oledc_setRotation(SCRN_ROT2);                    // Set rotation to 2.
 oledc_drawNumber(64,0);                          // Draw a floating point number with 2 place after decimal.
 pause(1000);                                     // Pause for one second to allow demo to complete.
   
//Clear Screen demo
  oledc_clear(0,0,oledc_getWidth(),oledc_getHeight());
 
 
//Set up for draw text, textwrap and scrolling demo.
  oledc_setRotation(2);                           // Set screen rotation to 2.
  oledc_setCursor(0,0,1);                         // Place cursor at position 0,0 on the screen with a cursor size of 1.
  
//Demo draw text and textwrap.
  oledc_clear(0,0,oledc_getWidth(),oledc_getHeight());
  oledc_setTextWrap(1);                           // Initiate text wrap. 0 = OFF, 1 = ON.
  oledc_drawText("Hello World");
  
  pause(1000);                                    // Pause for 1 second to demo sentence.
 
 
//Demo scrolling.
  oledc_scrollStart(-1,0);                        // Scroll to the left or right.
  pause(2800);                                    // Pause to demo scrolling feature.
  oledc_scrollStart(0,-1);                        // Scroll up or down. 
  pause(3900); 
  oledc_scrollStop();                             // Stop scrolling
  
  




    
}





/**
 * TERMS OF USE: MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
